@@ -6,10 +6,14 @@ import os
 import sys
 import traceback
 import uuid
-
+import gc
+import logging
+import gevent
 import gevent.pywsgi
+import gevent.util
 import socketio
 from engineio import static_files
+from gevent._greenlet_primitives import get_reachable_greenlets
 
 from suanpan import asyncio, error, g, runtime, utils
 from suanpan.arguments import Bool, BoolOrInt, Float, Int, String
@@ -114,8 +118,8 @@ class Stream(
             logger.debug(f"Loaded params: {params}")
             return params
         except Exception:  # pylint: disable=broad-except
-            tracebackInfo = traceback.format_exc()
-            logger.debug(f"Load params error: {tracebackInfo}")
+            # tracebackInfo = traceback.format_exc()
+            # logger.debug(f"Load params error: {tracebackInfo}")
             return {}
 
     def saveParams(self, params):
@@ -156,7 +160,19 @@ class Stream(
         logger.debug("Stream ALL Loop Closed")
 
         if self._exit_code != 0:
-            os._exit(self._exit_code)
+            logging.shutdown()
+            # gevent.util.print_run_info()
+
+            # glets = get_reachable_greenlets()
+            # running = []
+            # for ob in glets:
+            #     if isinstance(ob, gevent.Greenlet) and bool(ob):
+            #         running.append(ob)
+
+            # kill greenlet created by other modules
+            # running = [obj for obj in gc.get_objects() if isinstance(obj, gevent.Greenlet) and bool(obj)]
+            # gevent.killall(running)
+            sys.exit(self._exit_code)
 
     def close(self, code=0):
         self._exit_code = code
@@ -379,12 +395,13 @@ class StreamSIOLoop(StreamBaseLoop):
 
     def __init__(self, stream):
         super().__init__(stream)
-        self.sio = socketio.Server(async_mode="gevent", cors_allowed_origins="*", json=json)
+        self.sio = socketio.Server(async_mode="gevent", cors_allowed_origins="*", json=json, max_http_buffer_size=100000000)
         self.options = self._getDefaultOptions()
         self.extraStaticFiles = {}
         self.staticFiles = {}
         self._enabled = not g.serviceSioDisable
         self.server = None
+        self.web = None
 
     def _getDefaultOptions(self):
         options = Context()
@@ -481,6 +498,9 @@ class StreamSIOLoop(StreamBaseLoop):
             self.server.close()
         logger.debug("Stream SIO Loop Closed")
 
+    def setWebApp(self, web):
+        self.web = web
+
     def _init_win_server(self):
         p = None
         for _ in range(20):
@@ -512,7 +532,10 @@ class StreamSIOLoop(StreamBaseLoop):
     def start(self):
         logger.debug("Stream SIO Loop Starting...")
         self.staticFiles = self.getDefaultStaticFiles(self.staticFolder)
-        app = socketio.WSGIApp(self.sio, static_files=self.staticFiles)
+        if self.web:
+            app = self.web
+        else:
+            app = socketio.WSGIApp(self.sio, static_files=self.staticFiles)
         self.server = gevent.pywsgi.WSGIServer(
             ("", g.port), app, handler_class=WebSocketHandler
         )
